@@ -39,6 +39,28 @@ class TorchTagger:
         self.text_processor = TextProcessor(phraser=embedding.phraser, remove_stop_words=False, tokenizer=tokenizer)
 
 
+    def _get_pos_label(self, labels, pos_label):
+        """
+        Get positive label.
+        :param list[str/int] labels: List of data labels.
+        :param str/int pos_label: Label used as positive in metrics calculations. If not None, the same label is returned.
+        :return str/int pos_label: Label used as positive in metrics calculations.
+        """
+        if isinstance(pos_label, int):
+            # Get the original label
+            pos_label = self.label_reverse_index[pos_label]
+        if not pos_label:
+            if len(labels) == 2:
+                if "true" in labels:
+                    pos_label = "true"
+                else:
+                    raise exceptions.PosLabelNotSpecifiedError("Label set must contain label 'true' or positive label must be specified.")
+            else:
+                # Pos label is not important on multilabel dataset
+                pos_label = None
+        return pos_label
+
+
     @staticmethod
     def _get_tokenizer():
         """
@@ -59,7 +81,7 @@ class TorchTagger:
 
 
     @staticmethod
-    def evaluate_model(model, iterator):
+    def evaluate_model(model, iterator, classes, pos_label_index):
         """
         Evaluates the model using evaluation set & Tagging Report.
         :param: iterator: Instance of TorchText BucketIterator.
@@ -79,7 +101,7 @@ class TorchTagger:
             all_preds.extend(predictions.numpy())
             all_y.extend(batch.label.numpy())
             all_logprobs.extend(probabilities.numpy())
-        
+
         # flatten predictions
         all_preds = np.array(all_preds).flatten()
         all_logprobs = np.array(all_logprobs).flatten()
@@ -89,13 +111,13 @@ class TorchTagger:
         all_probs = np.clip(all_probs, 1e-5, 1-1e-5)
 
         all_y = np.array(all_y)
-        classes = list(set(all_y))
+        #classes = list(set(all_y))
         # report
-        report = TaggingReport(all_y, all_preds, all_probs, classes)
+        report = TaggingReport(all_y, all_preds, all_probs, classes=classes, pos_label_index=pos_label_index)
         report.val_loss = -np.sum(all_y*np.log(all_probs) + (1-all_y)*np.log(1-all_probs))/len(all_y)
         return report
 
-    def train(self, data_sample, num_epochs=5):
+    def train(self, data_sample, num_epochs=5, pos_label=None):
         """
         Trains model based on data sample.
         :param: dict data_sample: Dictonary containing class labels as keys and lists of examples as values.
@@ -106,7 +128,7 @@ class TorchTagger:
         # clear old epoch reports
         self.epoch_reports = []
         # prepare data
-        train_iterator, val_iterator, test_iterator, text_field = self._prepare_data(data_sample)
+        train_iterator, val_iterator, test_iterator, text_field = self._prepare_data(data_sample, pos_label=pos_label)
         # declare model
         model = self.model_arch(self.config, len(text_field.vocab), text_field.vocab.vectors, self.evaluate_model)
         # check cuda
@@ -125,7 +147,7 @@ class TorchTagger:
         model.add_loss_op(NLLLoss)
         # run epochs
         for i in range(self.config.max_epochs):
-            report = model.run_epoch(train_iterator, val_iterator, i)
+            report = model.run_epoch(train_iterator, val_iterator, i, self.labels, self.pos_label_index)
             # update class names
             report.classes = [self.label_reverse_index[cl] for cl in report.classes]
             self.epoch_reports.append(report)
@@ -147,7 +169,7 @@ class TorchTagger:
         with open(path, 'wb') as file:
             dill.dump(to_save, file)
         return True
-    
+
 
     def load(self, path):
         """Loads model from disk."""
@@ -166,7 +188,7 @@ class TorchTagger:
         tagger_path = tagger_object.model.path
         # load model
         return self.load(tagger_path)
-    
+
 
     def _set_loaded_values(self, loaded):
         """
@@ -205,7 +227,7 @@ class TorchTagger:
         return datafields, text_field
 
 
-    def _prepare_data(self, data_sample):
+    def _prepare_data(self, data_sample, pos_label=None):
         """
         Prepares training and validation iterators.
         :param: dict data_sample: Dictonary containing class labels as keys and lists of examples as values.
@@ -224,6 +246,13 @@ class TorchTagger:
         self.config.output_size = len(list(data_sample.keys()))
         # retrieve examples and labels from data sample
         examples, labels = self._get_examples_and_labels(data_sample)
+
+        self.labels = list(self.label_index.values())
+        # retrieve original_labels:
+        self.original_labels = list(self.label_index.keys())
+        # retrieve pos label
+        pos_label = self._get_pos_label(self.original_labels, pos_label)
+        self.pos_label_index = self.label_index[pos_label] if pos_label else pos_label
         # create datafields
         datafields, text_field = self._get_datafields()
         # create pandas dataframe and torchtext dataset
